// This file is part of InvenioAdministration
// Copyright (C) 2022 CERN.
//
// Invenio RDM Records is free software; you can redistribute it and/or modify it
// under the terms of the MIT License; see LICENSE file for more details.

export { default as AdminDetailsView } from "./AdminDetailsView";
export { default as DetailsComponent } from "./DetailsComponent";
