{#
    Copyright (C) 2022 CERN.

    Invenio Administration is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.
  #}


{% macro go_back() %}
  {% if request.referrer %}
    <div class="rel-mb-2">
      <a href="{{ request.referrer }}" class="ui mini button labeled icon rel-mr-1">
          <i class="ui icon left arrow" aria-hidden="true"></i>
          {{ _('Back')}}
      </a>
    </div>
  {% endif %}
{%- endmacro %}
