# -*- coding: utf-8 -*-
#
# Copyright (C) 2022-2024 CERN.
#
# invenio-administration is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Invenio module providing extensible administration panel."""

from .ext import InvenioAdministration

__version__ = "2.2.1"

__all__ = ["InvenioAdministration"]
